import ArtistInfoBox from "@/components/artists/ArtistInfoBox";
import ImageList from "@/components/lists/ImageList";
import prisma from "@/lib/prisma";

export default async function ArtistPage({ params }: { params: { artistSlug: string } }) {
  const { artistSlug } = await params;

  const artist = await prisma.artist.findUnique({
    where: {
      slug: artistSlug
    },
    include: {
      images: {
        include: {
          variants: true,
          album: { include: { gallery: true } },
          colors: { include: { color: true } }
        },
        orderBy: [{ sortIndex: 'asc' }, { imageName: 'asc' }]
      },
      socials: { where: { isVisible: true }, orderBy: [{ sortIndex: 'asc' }, { isPrimary: "desc" }] }
    }
  })

  if (!artist) {
    throw new Error("Artist not found")
  }

  return (
    <div className="max-w-7xl mx-auto px-4 py-12 space-y-12 flex flex-col items-center">
      <section className="text-center space-y-4">
        <h1 className="text-4xl font-bold tracking-tight">Artist: {artist.nickname ? artist.nickname : artist.displayName}</h1>
        <p className="text-lg text-muted-foreground">
          {artist.description ? artist.description : ""}
        </p>
      </section>
      <ArtistInfoBox artist={artist} />
      <ImageList images={artist.images} />
    </div>
  );
}