import ImageList from "@/components/lists/ImageList";
import prisma from "@/lib/prisma";

export default async function TagsSinglePage({ params }: { params: { id: string } }) {
  const { id } = await params;

  const tag = await prisma.tag.findUnique({
    where: {
      id,
    },
    include: {
      images: {
        include: {
          variants: true,
          album: { include: { gallery: true } },
          colors: { include: { color: true } }
        },
        orderBy: [{ sortIndex: 'asc' }, { imageName: 'asc' }]
      },
    }
  });

  if (!tag) {
    throw new Error("Tag not found")
  }

  return (
    <div className="max-w-7xl mx-auto px-4 py-12 space-y-12 flex flex-col items-center">
      <section className="text-center space-y-4">
        <h1 className="text-4xl font-bold tracking-tight">Tag: {tag.name}</h1>
        <p className="text-lg text-muted-foreground">
          {tag.description}
        </p>
      </section>
      <ImageList images={tag.images} />
    </div>
  );
}