"use client"

import { getBreadcrumbLabels } from "@/actions/breadcrumbs"
import { cn } from "@/lib/utils"
import { GalleryHorizontalEndIcon, HomeIcon, ImageIcon, ImagesIcon, InfoIcon, LayersIcon, TagIcon, UserIcon } from "lucide-react"
import Link from "next/link"
import { usePathname } from "next/navigation"
import { JSX, useEffect, useState } from "react"

const iconMap: Record<string, JSX.Element> = {
  home: <HomeIcon className="w-4 h-4" />,
  gallery: <GalleryHorizontalEndIcon className="w-4 h-4" />,
  album: <ImagesIcon className="w-4 h-4" />,
  category: <LayersIcon className="w-4 h-4" />,
  image: <ImageIcon className="w-4 h-4" />,
  tag: <TagIcon className="w-4 h-4" />,
  artist: <UserIcon className="w-4 h-4" />,
  about: <InfoIcon className="w-4 h-4" />,
}

type Crumb = {
  label: string
  href: string
  icon: keyof typeof iconMap
}

export default function Breadcrumbs() {
  const pathname = usePathname()
  const [labels, setLabels] = useState<Crumb[]>([])

  useEffect(() => {
    async function fetchLabels() {
      const data = await getBreadcrumbLabels(pathname)
      setLabels(data)
    }
    fetchLabels()
  }, [pathname])

  if (!labels.length) return null

  return (
    <nav className="flex items-center flex-wrap gap-1 text-muted-foreground">
      {labels.map((crumb, index) => {
        const isLast = index === labels.length - 1

        const item = (
          <span
            className={cn(
              "inline-flex items-center gap-1 px-3 py-1.5 rounded-md text-sm font-medium transition-colors",
              isLast
                ? "bg-muted pointer-events-none"
                : "bg-muted/50 hover:bg-muted text-foreground"
            )}
          >
            {iconMap[crumb.icon]}
            {crumb.label}
          </span>
        )

        return (
          <div key={index} className="flex items-center gap-1">
            {isLast ? item : <Link href={crumb.href} className="no-underline">{item}</Link>}
            {index < labels.length - 1 && <span className="mx-1 text-muted-foreground">{">"}</span>}
          </div>
        )
      })}
    </nav>
  )
}
