import prisma from "@/lib/prisma";
import CoverCard from "../cards/CoverCard";

export default async function GalleryList() {
  const galleries = await prisma.gallery.findMany({
    include: {
      coverImage: {
        include: {
          colors: {
            include: { color: true },
          },
        },
      },
    },
    orderBy: { sortIndex: 'asc' }
  });

  if (!galleries.length) return <p>There are no galleries here!</p>;

  return (
    <section>
      <div className="grid gap-6 sm:grid-cols-2 md:grid-cols-3 xl:grid-cols-4">
        {galleries.map((gallery) => (
          <CoverCard
            key={gallery.id}
            item={{
              id: gallery.id,
              name: gallery.name,
              slug: gallery.slug,
              coverImage: gallery.coverImage ?? undefined,
              type: "gallery",
            }}
          />
        ))}
      </div>
    </section>
  );
}
