import { Album, Gallery, Image } from "@/generated/prisma";
import ImageCard from "../cards/ImageCard";

type ImageWithItems = Image & {
  album: Album & {
    gallery: Gallery | null
  } | null
}

export default function ImageList({ images }: { images: ImageWithItems[] }) {
  if (!images.length) return <p>There are no images here!</p>;

  return (
    <section>
      <div className="grid gap-6 sm:grid-cols-2 md:grid-cols-3 xl:grid-cols-4">
        {images.map((image) => {
          const gallerySlug = image.album?.gallery?.slug ? image.album.gallery.slug : ''
          const albumSlug = image.album?.slug ? image.album.slug : ''
          return (<ImageCard key={image.id} image={image} gallerySlug={gallerySlug} albumSlug={albumSlug} />)
        })}
      </div>
    </section>
  );
}
